@@ -1,10 +1,10 @@
 //! Library for reading and writing binary data.
 //!
-//! If the `wasm32` feature is enabled then length 
-//! prefixed strings use a `u32` for the length so 
+//! If the `wasm32` feature is enabled then length
+//! prefixed strings use a `u32` for the length so
 //! that the encoded data is portable across platforms.
 //!
-//! Otherwise string length is encoded using `usize` which 
+//! Otherwise string length is encoded using `usize` which
 //! may vary across platforms.
 #![deny(missing_docs)]
 use std::io::{Read, Write};
@@ -13,9 +13,9 @@ mod error;
 mod filestream;
 mod memorystream;
 
+pub use error::BinaryError;
 pub use filestream::{FileStream, OpenType};
 pub use memorystream::MemoryStream;
-pub use error::BinaryError;
 
 /// Result type for binary errors.
 pub type Result<T> = std::result::Result<T, BinaryError>;
@@ -69,14 +69,6 @@ pub struct BinaryReader<'a> {
 }
 
 impl<'a> BinaryReader<'a> {
-
-    /*
-    /// Create a binary reader.
-    pub fn new(stream: &'a mut impl Stream) -> Self {
-        Self::new_endian(stream, Default::default())
-    }
-    */
-
     /// Create a binary reader with the given endianness.
     pub fn new(stream: &'a mut impl Stream, endian: Endian) -> Self {
         Self { stream, endian }
@@ -108,6 +100,11 @@ impl<'a> BinaryReader<'a> {
         Ok(String::from_utf8(chars)?)
     }
 
+    /// Read a character from the stream.
+    pub fn read_char(&mut self) -> Result<char> {
+        Ok(std::char::from_u32(self.read_u32()?).ok_or_else(|| BinaryError::InvalidChar)?)
+    }
+
     /// Read a `bool` from the stream.
     pub fn read_bool(&mut self) -> Result<bool> {
         let value = self.read_u8()?;
@@ -231,14 +228,6 @@ pub struct BinaryWriter<'a> {
 }
 
 impl<'a> BinaryWriter<'a> {
-
-    /*
-    /// Create a binary writer.
-    pub fn new(stream: &'a mut impl Stream) -> Self {
-        Self::new_endian(stream, Default::default())
-    }
-    */
-
     /// Create a binary writer with the given endianness.
     pub fn new(stream: &'a mut impl Stream, endian: Endian) -> Self {
         Self { stream, endian }
@@ -256,7 +245,7 @@ impl<'a> BinaryWriter<'a> {
 
     /// Write a length-prefixed `String` to the stream.
     ///
-    /// The length of the `String` is written as a `usize` 
+    /// The length of the `String` is written as a `usize`
     /// unless the `wasm32` feature is enabled
     /// in which case the length is a `u32`.
     pub fn write_string<S: AsRef<str>>(&mut self, value: S) -> Result<usize> {
@@ -269,6 +258,11 @@ impl<'a> BinaryWriter<'a> {
         Ok(self.stream.write(&bytes.to_vec())?)
     }
 
+    /// Write a character to the stream.
+    pub fn write_char(&mut self, v: char) -> Result<usize> {
+        self.write_u32(v as u32)
+    }
+
     /// Write a `bool` to the stream.
     pub fn write_bool(&mut self, value: bool) -> Result<usize> {
         let written = self.write_u8(if value { 1 } else { 0 })?;
@@ -340,3 +334,15 @@ impl<'a> BinaryWriter<'a> {
         Ok(self.stream.write(data.as_ref())?)
     }
 }
+
+/// Trait for encoding to binary.
+pub trait Encode {
+    /// Encode self into the binary writer.
+    fn encode(&self, writer: &mut BinaryWriter) -> Result<()>;
+}
+
+/// Trait for decoding from binary.
+pub trait Decode {
+    /// Decode from the binary reader into self.
+    fn decode(&mut self, reader: &mut BinaryReader) -> Result<()>;
+}
